CFPropertyList

Struct CFPropertyList 

pub struct CFPropertyList;
Namespace for property-list parse / serialize helpers.

Implementations

Source

impl CFPropertyList

pub fn create_deep_copy( property_list: &dyn AsCFType, options: CFPropertyListMutabilityOptions, ) -> Result<CFType, CFError>

Deep-copy a property list, optionally changing its mutability semantics.

pub fn create_with_data( data: &CFData, options: CFPropertyListMutabilityOptions, ) -> Result<(CFType, CFPropertyListFormat), CFPropertyListError>

Decode a property list from an in-memory data blob.

pub fn create_with_stream( stream: &CFReadStream, stream_length: usize, options: CFPropertyListMutabilityOptions, ) -> Result<(CFType, CFPropertyListFormat), CFPropertyListError>

Decode a property list from an already-open Core Foundation read stream.

pub fn create_data( property_list: &dyn AsCFType, format: CFPropertyListFormat, options: u64, ) -> Result<CFData, CFPropertyListError>

Serialize a property list into a CFData blob.

pub fn write( property_list: &dyn AsCFType, stream: &CFWriteStream, format: CFPropertyListFormat, options: u64, ) -> Result<usize, CFPropertyListError>

Write a serialized property list to an already-open Core Foundation write stream.

pub fn is_valid( property_list: &dyn AsCFType, format: CFPropertyListFormat, ) -> bool

Validate whether a Core Foundation object can be serialized as a property list.