CFRunLoop

Struct CFRunLoop 

pub struct CFRunLoop(/* private fields */);

Implementations

Source

impl CFRunLoop

pub fn from_raw(ptr: *mut c_void) -> Option<Self>

pub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>

Retain a borrowed pointer before wrapping it.

Safety

ptr must be NULL or a valid pointer of the expected Core Foundation type.

pub const fn as_ptr(&self) -> *mut c_void

pub fn type_id() -> usize

pub fn into_cf_type(self) -> CFType

Source

impl CFRunLoop

pub fn current() -> Self

Current thread’s run loop.

pub fn main() -> Self

Main thread run loop.

pub fn run_in_default_mode( &self, duration: Duration, return_after_source_handled: bool, ) -> CFRunLoopRunResult

Run the current thread’s run loop in the default mode for duration.

pub fn wake_up(&self)

Wake the run loop.

pub fn stop(&self)

Stop the run loop.

pub fn add_timer(&self, timer: &CFTimer)

Add a timer to the run loop in the default mode.