CGContext

Struct CGContext 

pub struct CGContext { /* private fields */ }
Available on crate feature cg only.
Reference-counted CGContextRef backed by a bitmap.

Implementations

Source

impl CGContext

pub const unsafe fn from_raw(ptr: *mut c_void) -> Self

Wrap a raw CGContextRef pointer — takes ownership without retaining.

Safety

ptr must be a non-null CGContextRef whose ownership the caller is transferring to the returned CGContext.

pub fn new_rgba8(width: usize, height: usize) -> Result<Self, CFError>

Create a premultiplied-last RGBA8 bitmap context.

Errors

Returns CFError if Core Graphics fails to create the bitmap context.

pub fn new_grayscale(width: usize, height: usize) -> Result<Self, CFError>

Create an 8-bit grayscale bitmap context.

Errors

Returns CFError if Core Graphics fails to create the bitmap context.

pub fn width(&self) -> usize

Width in pixels.

pub fn height(&self) -> usize

Height in pixels.

pub fn bytes_per_row(&self) -> usize

Bytes per row.

pub fn bits_per_component(&self) -> usize

Bits per component.

pub fn bits_per_pixel(&self) -> usize

Bits per pixel.

pub fn data(&self) -> *mut u8

Raw bitmap data pointer.

pub fn color_space(&self) -> Option<CGColorSpace>

The context color space, if one is set.

pub fn alpha_info(&self) -> u32

The raw CGImageAlphaInfo value for the bitmap context.

pub fn as_bytes(&self) -> &[u8]

The bitmap storage as immutable bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

The bitmap storage as mutable bytes.

pub fn set_rgb_fill_color(&self, r: f64, g: f64, b: f64, a: f64)

Set the current fill color in DeviceRGB.

pub fn set_rgb_stroke_color(&self, r: f64, g: f64, b: f64, a: f64)

Set the current stroke color in DeviceRGB.

pub fn set_line_width(&self, w: f64)

Set the stroke line width.

pub fn clear_rect(&self, x: f64, y: f64, w: f64, h: f64)

Clear a rectangle to transparent black.

pub fn fill_rect(&self, x: f64, y: f64, w: f64, h: f64)

Fill a rectangle.

pub fn stroke_rect(&self, x: f64, y: f64, w: f64, h: f64)

Stroke a rectangle.

pub fn begin_path(&self)

Begin a new path.

pub fn close_path(&self)

Close the current path.

pub fn move_to(&self, x: f64, y: f64)

Move the current point.

pub fn add_line_to(&self, x: f64, y: f64)

Add a line segment to the current path.

pub fn add_rect(&self, x: f64, y: f64, w: f64, h: f64)

Add a rectangle to the current path.

pub fn add_ellipse_in_rect(&self, x: f64, y: f64, w: f64, h: f64)

Add an ellipse inscribed in the rectangle.

pub fn fill_path(&self)

Fill the current path.

pub fn stroke_path(&self)

Stroke the current path.

pub fn draw_image(&self, x: f64, y: f64, w: f64, h: f64, image: &CGImage)

Draw an image into the target rectangle.

pub fn translate(&self, tx: f64, ty: f64)

Translate the current transformation matrix.

pub fn scale(&self, sx: f64, sy: f64)

Scale the current transformation matrix.

pub fn rotate(&self, radians: f64)

Rotate the current transformation matrix.

pub fn save_g_state(&self)

Save the current graphics state.

pub fn restore_g_state(&self)

Restore the most recently saved graphics state.

pub fn snapshot_to_image(&self) -> Option<CGImage>

Snapshot the current bitmap contents to a CGImage.

pub const fn as_ptr(&self) -> *mut c_void

Raw CGContextRef pointer.