Struct CMClock
Source pub struct CMClock { }
Available on crate feature cm only.
CMClock wrapper for synchronization clock
Represents a Core Media clock used for time synchronization.
Available on macOS 13.0+.
Wraps a +1 retained CMClockRef and returns None for null.
Returns the raw pointer to the underlying CMClock
Get the current time from this clock
Note: Returns invalid time. Use as_ptr() with Core Media APIs directly
for full clock functionality.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.