CMSampleTimingInfo

Struct CMSampleTimingInfo 

#[repr(C)]
pub struct CMSampleTimingInfo { pub duration: CMTime, pub presentation_time_stamp: CMTime, pub decode_time_stamp: CMTime, }
Available on crate feature cm only.
Sample timing information

Contains timing data for a media sample (audio or video frame).

Examples

use apple_cf::cm::{CMSampleTimingInfo, CMTime};

let timing = CMSampleTimingInfo::new();
assert!(!timing.is_valid());

let duration = CMTime::new(1, 30);
let pts = CMTime::new(100, 30);
let dts = CMTime::new(100, 30);
let timing = CMSampleTimingInfo::with_times(duration, pts, dts);
assert!(timing.is_valid());

Fields

duration: CMTimepresentation_time_stamp: CMTimedecode_time_stamp: CMTime

Implementations

Source

impl CMSampleTimingInfo

pub const fn new() -> Self

Create a new timing info with all times set to invalid

Examples
use apple_cf::cm::CMSampleTimingInfo;

let timing = CMSampleTimingInfo::new();
assert!(!timing.is_valid());
pub const fn with_times( duration: CMTime, presentation_time_stamp: CMTime, decode_time_stamp: CMTime, ) -> Self

Create timing info with specific values

pub const fn is_valid(&self) -> bool

Check if all timing fields are valid Returns whether this time carries Core Media’s valid flag.

pub const fn has_valid_presentation_time(&self) -> bool

Check if presentation timestamp is valid

pub const fn has_valid_decode_time(&self) -> bool

Check if decode timestamp is valid

pub const fn has_valid_duration(&self) -> bool

Check if duration is valid

pub fn presentation_seconds(&self) -> Option<f64>

Get the presentation timestamp in seconds

pub fn decode_seconds(&self) -> Option<f64>

Get the decode timestamp in seconds

pub fn duration_seconds(&self) -> Option<f64>

Get the duration in seconds