CMTimeRange

Struct CMTimeRange 

#[repr(C)]
pub struct CMTimeRange { pub start: CMTime, pub duration: CMTime, }
Available on crate feature cm only.
CMTimeRange representation matching Core Media’s CMTimeRange.

use apple_cf::cm::{CMTime, CMTimeRange};

let range = CMTimeRange::new(CMTime::new(0, 600), CMTime::new(300, 600));
assert_eq!(range.end(), CMTime::new(300, 600));
assert!(range.contains_time(CMTime::new(150, 600)));

Fields

start: CMTimeduration: CMTime

Implementations

Source

impl CMTimeRange

pub const INVALID: Self

Core Media’s invalid time-range sentinel (kCMTimeRangeInvalid).

pub const fn new(start: CMTime, duration: CMTime) -> Self

Creates a Core Media time range from a start time and duration.

pub fn end(&self) -> CMTime

Returns the range end time via CMTimeRangeGetEnd.

pub const fn is_valid(&self) -> bool

Returns whether both the start and duration are valid CMTime values.

pub fn contains_time(&self, time: CMTime) -> bool

Returns whether this range contains the supplied CMTime.

pub fn contains_range(&self, other: Self) -> bool

Returns whether this range fully contains other.

pub fn intersection(&self, other: Self) -> Self

Returns the intersection of this range and other.

pub fn union(&self, other: Self) -> Self

Returns the union of this range and other.