CFStringGetCharacterFromInlineBuffer

Function CFStringGetCharacterFromInlineBuffer 

pub unsafe fn CFStringGetCharacterFromInlineBuffer(
    buf: *mut CFStringInlineBuffer,
    idx: CFIndex,
) -> UniChar
Returns a character from a CFStringInlineBuffer. Wraps CFStringGetCharacterFromInlineBuffer.

Safety

buf must point to an initialized inline buffer created for the referenced string, and it must remain valid for the duration of the call.