Safe Core Foundation wrappers.
This module provides lightweight, dependency-free wrappers for the most common Core Foundation value, collection, locale, formatter, and runtime types used throughout the Apple media stack.
Structs
- CFArray
- CFAttributed
String - CFBag
- CFBundle
- CFCalendar
- CFCharacter
Set - CFData
- CFDate
- CFDate
Formatter - CFDictionary
- CFError
- CFFile
Descriptor - CFFile
Security - CFLocale
- CFMessage
Port - CFMutable
Set - CFNotification
Center - CFNumber
- CFNumber
Formatter - CFPreferences
- Core Foundation preferences helpers.
- CFProperty
List - Namespace for property-list parse / serialize helpers.
- CFProperty
List Mutability Options - Mutability options for property-list decoding and deep copies.
- CFRead
Stream - CFRun
Loop - CFSet
- CFSocket
- CFStream
Pair - Paired Core Foundation streams backed by a shared in-memory buffer.
- CFString
- CFTime
Zone - CFTimer
- CFTree
- Safe wrapper around a Swift-backed
CFTreehelper. - CFType
- Owned, type-erased
CFTypeRef. - CFURL
- CFUUID
- CFWrite
Stream - CFXML
- Tiny wrapper around the remaining useful
CFXMLhelpers.
Enums
- CFDate
Formatter Style CFDateFormatterStylevalues mirrored from Core Foundation.- CFNumber
Formatter Style CFNumberFormatterStylevalues mirrored from Core Foundation.- CFProperty
List Error - Errors returned by property-list decode / serialize helpers.
- CFProperty
List Format CFPropertyListFormatvalues mirrored from Core Foundation.- CFRun
Loop RunResult - Result codes from
CFRunLoopRunInMode. - CFSet
Callbacks - Safe representation of the
CFSetCallBacks/kCFTypeSetCallBacks/kCFCopyStringSetCallBacksconfiguration used when creating sets.
Traits
- AsCF
Type - Trait for Core Foundation values that can be inserted into CF collections.