pub struct CFDate(/* private fields */);Implementations
Sourceimpl CFDate
impl CFDate
pub fn from_raw(ptr: *mut c_void) -> Option<Self>
Sourcepub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
pub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
Retain a borrowed pointer before wrapping it.
Safety
ptr must be NULL or a valid pointer of the expected Core Foundation type.
pub const fn as_ptr(&self) -> *mut c_void
pub fn type_id() -> usize
pub fn into_cf_type(self) -> CFType
Sourceimpl CFDate
impl CFDate
Sourcepub fn from_absolute_time(absolute_time: f64) -> Self
pub fn from_absolute_time(absolute_time: f64) -> Self
Create a date from Core Foundation absolute time (seconds since 2001-01-01 00:00:00 UTC).
Sourcepub fn from_system_time(time: SystemTime) -> Self
pub fn from_system_time(time: SystemTime) -> Self
Convert from a Rust SystemTime.
Sourcepub fn absolute_time(&self) -> f64
pub fn absolute_time(&self) -> f64
Core Foundation absolute time.
Sourcepub fn to_system_time(&self) -> Option<SystemTime>
pub fn to_system_time(&self) -> Option<SystemTime>
Convert to SystemTime when representable.