pub struct CFDateFormatter(/* private fields */);Implementations
Sourceimpl CFDateFormatter
impl CFDateFormatter
pub fn from_raw(ptr: *mut c_void) -> Option<Self>
Sourcepub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
pub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
Retain a borrowed pointer before wrapping it.
Safety
ptr must be NULL or a valid pointer of the expected Core Foundation type.
pub const fn as_ptr(&self) -> *mut c_void
pub fn type_id() -> usize
pub fn into_cf_type(self) -> CFType
Sourceimpl CFDateFormatter
impl CFDateFormatter
Sourcepub fn new(
locale: Option<&CFLocale>,
date_style: CFDateFormatterStyle,
time_style: CFDateFormatterStyle,
) -> Self
pub fn new( locale: Option<&CFLocale>, date_style: CFDateFormatterStyle, time_style: CFDateFormatterStyle, ) -> Self
Create a date formatter for the given locale and styles.
Sourcepub fn format_date(&self, date: &CFDate) -> CFString
pub fn format_date(&self, date: &CFDate) -> CFString
Format a date into a localized string.