pub struct CFMessagePort(/* private fields */);Implementations
Sourceimpl CFMessagePort
impl CFMessagePort
pub fn from_raw(ptr: *mut c_void) -> Option<Self>
Sourcepub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
pub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
Retain a borrowed pointer before wrapping it.
Safety
ptr must be NULL or a valid pointer of the expected Core Foundation type.
pub const fn as_ptr(&self) -> *mut c_void
pub fn type_id() -> usize
pub fn into_cf_type(self) -> CFType
Sourceimpl CFMessagePort
impl CFMessagePort
Sourcepub fn create_echo_local(name: &str) -> Self
pub fn create_echo_local(name: &str) -> Self
Create a local message port that echoes request data back as the reply.
Sourcepub fn connect_remote(name: &str) -> Option<Self>
pub fn connect_remote(name: &str) -> Option<Self>
Connect to an existing remote message port.
Sourcepub fn send_request(
&self,
bytes: &[u8],
timeout: Duration,
) -> Result<Vec<u8>, i32>
pub fn send_request( &self, bytes: &[u8], timeout: Duration, ) -> Result<Vec<u8>, i32>
Send a request and copy the reply bytes.
Sourcepub fn invalidate(&self)
pub fn invalidate(&self)
Invalidate the message port.