CFMutableSet

Struct CFMutableSet 

pub struct CFMutableSet(/* private fields */);

Implementations

Source

impl CFMutableSet

pub fn from_raw(ptr: *mut c_void) -> Option<Self>

pub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>

Retain a borrowed pointer before wrapping it.

Safety

ptr must be NULL or a valid pointer of the expected Core Foundation type.

pub const fn as_ptr(&self) -> *mut c_void

pub fn type_id() -> usize

pub fn into_cf_type(self) -> CFType

Source

impl CFMutableSet

pub fn new() -> Self

Create an empty mutable set using Core Foundation type callbacks.

pub fn with_callbacks(capacity: usize, callbacks: CFSetCallbacks) -> Self

Create an empty mutable set with explicit callback semantics.

pub fn from_values(values: &[&dyn AsCFType]) -> Self

Create a mutable set from borrowed Core Foundation values using type callbacks.

pub fn from_values_with_callbacks( values: &[&dyn AsCFType], callbacks: CFSetCallbacks, ) -> Self

Create a mutable set from borrowed Core Foundation values with explicit callback semantics.

pub fn copy(&self) -> CFSet

Create an immutable retained copy of this set.

pub fn mutable_copy(&self, capacity: usize) -> Self

Create a mutable retained copy of this set.

pub fn len(&self) -> usize

Number of values in the set.

pub fn is_empty(&self) -> bool

Whether the set is empty.

pub fn contains(&self, candidate: &dyn AsCFType) -> bool

Whether the set contains candidate.

pub fn count_of_value(&self, candidate: &dyn AsCFType) -> usize

Number of times candidate appears in the set (0 or 1).

pub fn values(&self) -> Vec<CFType>

Copy all values into a Rust vector.

pub fn add(&self, candidate: &dyn AsCFType)

Add candidate if it is not already present.

pub fn replace(&self, candidate: &dyn AsCFType)

Replace the matching value if it is already present.

pub fn set(&self, candidate: &dyn AsCFType)

Insert or replace candidate.

pub fn remove(&self, candidate: &dyn AsCFType)

Remove candidate if it exists.

pub fn clear(&self)

Remove every value from the set.

pub fn for_each<F>(&self, callback: F)
where F: FnMut(CFType),

Call callback once for each value in the set.