pub struct CFNumberFormatter(/* private fields */);Implementations
Sourceimpl CFNumberFormatter
impl CFNumberFormatter
pub fn from_raw(ptr: *mut c_void) -> Option<Self>
Sourcepub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
pub unsafe fn from_raw_retained(ptr: *mut c_void) -> Option<Self>
Retain a borrowed pointer before wrapping it.
Safety
ptr must be NULL or a valid pointer of the expected Core Foundation type.
pub const fn as_ptr(&self) -> *mut c_void
pub fn type_id() -> usize
pub fn into_cf_type(self) -> CFType
Sourceimpl CFNumberFormatter
impl CFNumberFormatter
Sourcepub fn new(locale: Option<&CFLocale>, style: CFNumberFormatterStyle) -> Self
pub fn new(locale: Option<&CFLocale>, style: CFNumberFormatterStyle) -> Self
Create a number formatter for the given locale and style.
Sourcepub fn format_number(&self, number: &CFNumber) -> CFString
pub fn format_number(&self, number: &CFNumber) -> CFString
Format a number into a string.
Sourcepub fn parse_number(&self, string: &CFString) -> Option<CFNumber>
pub fn parse_number(&self, string: &CFString) -> Option<CFNumber>
Parse a string into a Core Foundation number.