CFRunLoop

Struct CFRunLoop 

pub struct CFRunLoop(/* private fields */);
Safe wrapper around a retained Core Foundation CFRunLoop reference.

Implementations

Source

impl CFRunLoop

pub unsafe fn from_raw(ptr: *mut c_void) -> Option<Self>

Adopts a +1 retained CFRunLoop pointer and returns None for null.

Safety

A non-null ptr must be a live CFRunLoop pointer of the exact dynamic type carrying one retain transferred to this wrapper. The caller must not release or separately adopt that transferred retain.

pub unsafe fn from_raw_borrowed(ptr: *mut c_void) -> Option<Self>

Retains a +0 borrowed CFRunLoop pointer and returns an owned wrapper.

Safety

A non-null ptr must be a live CFRunLoop pointer of the exact dynamic type for the duration of the retain call.

pub const fn as_ptr(&self) -> *mut c_void

Borrows the raw +0 Core Foundation pointer while self remains alive.

pub fn type_id() -> usize

Returns the Core Foundation type ID for CFRunLoop.

pub fn into_cf_type(self) -> CFType

Consumes this wrapper and returns the erased CFType.

Source

impl CFRunLoop

pub fn current() -> Self

Current thread’s run loop.

pub fn main() -> Self

Main thread run loop.

pub fn run_in_default_mode( &self, duration: Duration, return_after_source_handled: bool, ) -> CFRunLoopRunResult

Run the current thread’s run loop in the default mode for duration.

pub fn wake_up(&self)

Wake the run loop.

pub fn stop(&self)

Stop the run loop.

pub fn add_timer(&self, timer: &CFTimer)

Add a timer to the run loop in the default mode.